@@ -258,7 +258,7 @@ dplyr_col_modify.grouped_ts <- dplyr_col_modify.tbl_ts
 dplyr_reconstruct.tbl_ts <- function(data, template) {
   template <- rename_join_tsibble(data, template)
   update_meta(data, template,
-    ordered = is_ordered(template), interval = is_regular(template),
+    ordered = NULL, interval = is_regular(template),
     validate = TRUE)
 }
 
